#
# spec file for package cm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cm
Version:        0.4.3
Release:        2.3
Summary:        Class polynomial computation via floating point approximations
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.multiprecision.org/cm/
#Git-Clone:     https://gitlab.inria.fr/enge/cm
Source:         http://www.multiprecision.org/downloads/%name-%version.tar.gz
Source2:        http://www.multiprecision.org/downloads/%name-%version.tar.gz.asc
Source3:        %name.keyring
Patch1:         0001-Include-standard-header-file.patch
BuildRequires:  flint-devel >= 3
BuildRequires:  gmp-devel >= 4.3.2
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  mpc-devel >= 1
BuildRequires:  mpfr-devel >= 3
BuildRequires:  mpfrcx-devel >= 0.6.3
BuildRequires:  pari-devel >= 2.11
BuildRequires:  zlib-devel

%description
The CM software implements the construction of ring class fields of
imaginary quadratic number fields and of elliptic curves with complex
multiplication via floating point approximations.

%package devel
Summary:        Development files for the CM computation software
Group:          Development/Libraries/C and C++
Requires:       libcm1 = %version-%release
Requires:       mpc-devel
Requires:       mpfrcx-devel
Requires:       zlib-devel

%description devel
The CM software implements the construction of ring class fields of
imaginary quadratic number fields and of elliptic curves with complex
multiplication via floating point approximations.

This subpackage provides the development headers for it.

%package -n libcm1
Summary:        Multi-precision floating-point interval arithmetic computation library
Group:          System/Libraries

%description -n libcm1
The CM software implements the construction of ring class fields of
imaginary quadratic number fields and of elliptic curves with complex
multiplication via floating point approximations.

It includes libraries that can be called from within a C program.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%check
if ! %make_build check; then
	cat tests/test-suite.log
	exit 1
fi

%ldconfig_scriptlets -n libcm1

%post
%install_info --info-dir="%_infodir" "%_infodir/cm.info.gz"

%postun
%install_info_delete --info-dir="%_infodir" "%_infodir/cm.info.gz"

%files
%_bindir/classpol
%_bindir/cm
%_bindir/ecpp*
%_datadir/cm/
%_infodir/cm.info*

%files devel
%_includedir/cm*.h
%_libdir/libcm*.so

%files -n libcm1
%_libdir/libcm.so.1*

%changelog
* Sat Nov  2 2024 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Include-standard-header-file.patch to resolve
  gcc>=14 FTBFS (preprocessor result of gmp.h changes depending
  on stdio.h being included before or not)
* Thu Apr 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.4.3
  * FLINT3 support
  * Add an upper bound on the permitted class number in ECPP, to
    avoid choosing discriminants for which class polynomials
    cannot be computed in reasonable time and with reasonable
    memory.
- Delete flint3.diff (obsolete)
* Sun Oct 22 2023 Jan Engelhardt <jengelh@inai.de>
- Add flint3.diff to have the build succeed with flint-3.
* Sat Jun 24 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.4.2
  * When ECPP certificates are output to a file, a second file in
    Primo format is created automatically.
  * ECPP certificate creation uses class field towers
    unconditionally.
  * An optional primality test is carried out before starting ECPP.
  * For larger numbers, the BPSW primality test of GMP is replaced
    by a Miller-Rabin test to base 2.
  * New command line options make it possible to compute only the
    first or only the second phase.
  * Phase 2 results are stored in any order as they come in, which
    requires the file format to change. Checkpoint files ending in
    .cert2 from previous releases are not compatible.
  * Add an optional dependency on FLINT to speed up root finding
    in the second ECPP phase.
* Sat Aug 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0.4.0+gb2b8d4bd
  * Fix 32-bit testsuite run
* Thu Jun 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.4.0
  * Add a decomposition of the class field into a tower of prime
    degree extensions following the algorithm described in A.
    Enge and F. Morain, Fast Decomposition of Polynomials with
    Known Galois Group.
  * Add an implementation of the fastECPP primality proving
    algorithm, complete with a version running over MPI.
* Mon Sep 28 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.3.1
  * Correct a bug in computing powers of 2.
    (fixed: "left shift count >= width of type")
* Thu Sep 17 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 0.3) for build.opensuse.org
